@@ -29,9 +29,16 @@ panel.blandaltman <- function(x, y, ...){
     abline(h=mu.diff - 2*sd.diff, lty=3, lwd=2, col="red")
 }
 
-agree.plot <- function(ratings){
-    if(!is.matrix(ratings) || ncol(ratings) < 2)
-        stop("'ratings' has to be a matrix of at least two columns.")
+agree.plot <- function(ratings, NAaction=c("fail", "omit")){
+    if(!is.matrix(ratings) || ncol(ratings) < 2 || nrow(ratings) < 2)
+        stop("'ratings' has to be a matrix of at least two columns and two rows.")
+    na <- match.arg(NAaction)
+    ratings <- switch(na,
+                      fail = na.fail(ratings),
+                      omit = na.omit(ratings))
+    if(!is.matrix(ratings) || ncol(ratings) < 2|| nrow(ratings) < 2)
+        stop("'ratings' has to be a matrix of at least two columns and two rows after removing missing values.")
+
     pairs(ratings, lower.panel=panel.blandaltman, upper.panel=panel.identity,
           xaxt="n", yaxt="n", labels=paste("Rater", 1:ncol(ratings)))
 
